@@ -1,6 +1,9 @@
 #if defined(__GNUC__)
 typedef long long int64;
 typedef unsigned long long uint64;
+#ifndef _WIN32
+#define __declspec(x)
+#endif
 #elif defined(__TINYC__)
 #include <stdarg.h>
 #define __builtin_va_list va_list
@@ -10,6 +13,8 @@ typedef unsigned long long uint64;
 #define strcasecmp stricmp
 #define strncasecmp strnicmp
 #define __declspec(x) __attribute__((x))
+#else
+#define __declspec(x)
 #endif
 typedef long long int64;
 typedef unsigned long long uint64;
@@ -22,6 +27,16 @@ typedef unsigned __int64 uint64;
 #else
 #define __ENDIAN_PAD(x) 0
 #endif
+#include <stdint.h>
+#include <sys/types.h>
+extern void *  __ecereNameSpace__ecere__com__eSystem_New(unsigned int size);
+
+extern void *  __ecereNameSpace__ecere__com__eSystem_New0(unsigned int size);
+
+extern void *  __ecereNameSpace__ecere__com__eSystem_Renew(void *  memory, unsigned int size);
+
+extern void *  __ecereNameSpace__ecere__com__eSystem_Renew0(void *  memory, unsigned int size);
+
 extern struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecere__sys__BTNode;
 
 struct __ecereNameSpace__ecere__sys__BTNode;
@@ -32,7 +47,7 @@ struct __ecereNameSpace__ecere__sys__BinaryTree
 {
 struct __ecereNameSpace__ecere__sys__BTNode * root;
 int count;
-int (*  CompareKey)(struct __ecereNameSpace__ecere__sys__BinaryTree * tree, unsigned int a, unsigned int b);
+int (*  CompareKey)(struct __ecereNameSpace__ecere__sys__BinaryTree * tree, uintptr_t a, uintptr_t b);
 void (*  FreeKey)(void *  key);
 } __attribute__ ((gcc_struct));
 
@@ -105,6 +120,8 @@ struct __ecereNameSpace__ecere__sys__OldList templatized;
 int numParams;
 } __attribute__ ((gcc_struct));
 
+extern long long __ecereNameSpace__ecere__com__eClass_GetProperty(struct __ecereNameSpace__ecere__com__Class * _class, char *  name);
+
 extern struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecere__com__Instance;
 
 struct __ecereNameSpace__ecere__com__Instance
@@ -128,9 +145,9 @@ struct __ecereNameSpace__ecere__com__Class * _class;
 char *  dataTypeString;
 struct __ecereNameSpace__ecere__com__Class * dataTypeClass;
 struct __ecereNameSpace__ecere__com__Instance * dataType;
-void (*  Set)();
-int (*  Get)();
-unsigned int (*  IsSet)();
+void (*  Set)(void * , int);
+int (*  Get)(void * );
+unsigned int (*  IsSet)(void * );
 void *  data;
 void *  symbol;
 int vid;
@@ -251,8 +268,6 @@ int __ecereVMethodID_class_OnCompare;
 
 int __ecereVMethodID_class_OnCopy;
 
-int __ecereVMethodID_class_OnDisplay;
-
 int __ecereVMethodID_class_OnEdit;
 
 int __ecereVMethodID_class_OnFree;
@@ -267,6 +282,8 @@ int __ecereVMethodID_class_OnSerialize;
 
 int __ecereVMethodID_class_OnUnserialize;
 
+struct __ecereNameSpace__ecere__com__Class * __ecereClass_double;
+
 struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecere__com__AVLNode;
 
 struct __ecereNameSpace__ecere__com__Property * __ecereProp___ecereNameSpace__ecere__com__AVLNode_maximum;
@@ -537,6 +554,8 @@ int __ecereVMethodID___ecereNameSpace__ecere__sys__FileSystem_Stats;
 
 struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecere__sys__NamedLink;
 
+struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecere__sys__NamedLink64;
+
 struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecere__sys__OldLink;
 
 struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecere__sys__OldList;
@@ -545,12 +564,18 @@ struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecer
 
 struct __ecereNameSpace__ecere__com__Class * __ecereClass___ecereNameSpace__ecere__sys__TempFile;
 
+struct __ecereNameSpace__ecere__com__Class * __ecereClass_float;
+
 struct __ecereNameSpace__ecere__com__Class * __ecereClass_int;
 
+struct __ecereNameSpace__ecere__com__Class * __ecereClass_int64;
+
 struct __ecereNameSpace__ecere__com__Class * __ecereClass_uint;
 
 struct __ecereNameSpace__ecere__com__Class * __ecereClass_uint64;
 
+struct __ecereNameSpace__ecere__com__Class * __ecereClass_uintptr;
+
 void __ecereRegisterModule_BufferedFile(struct __ecereNameSpace__ecere__com__Instance * module);
 
 void __ecereUnregisterModule_BufferedFile(struct __ecereNameSpace__ecere__com__Instance * module);
@@ -694,9 +719,6 @@ __ecereVMethodID_class_OnCompare = method->vid;
 method = __ecereNameSpace__ecere__com__eClass_FindMethod(_class, "OnCopy", module);
 if(method)
 __ecereVMethodID_class_OnCopy = method->vid;
-method = __ecereNameSpace__ecere__com__eClass_FindMethod(_class, "OnDisplay", module);
-if(method)
-__ecereVMethodID_class_OnDisplay = method->vid;
 method = __ecereNameSpace__ecere__com__eClass_FindMethod(_class, "OnEdit", module);
 if(method)
 __ecereVMethodID_class_OnEdit = method->vid;
@@ -718,6 +740,7 @@ __ecereVMethodID_class_OnSerialize = method->vid;
 method = __ecereNameSpace__ecere__com__eClass_FindMethod(_class, "OnUnserialize", module);
 if(method)
 __ecereVMethodID_class_OnUnserialize = method->vid;
+__ecereClass_double = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "double");
 __ecereClass___ecereNameSpace__ecere__com__AVLNode = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "ecere::com::AVLNode");
 __ecereProp___ecereNameSpace__ecere__com__AVLNode_maximum = _property = __ecereNameSpace__ecere__com__eClass_FindProperty(__ecereClass___ecereNameSpace__ecere__com__AVLNode, "maximum", module);
 __ecereProp___ecereNameSpace__ecere__com__AVLNode_minimum = _property = __ecereNameSpace__ecere__com__eClass_FindProperty(__ecereClass___ecereNameSpace__ecere__com__AVLNode, "minimum", module);
@@ -1027,13 +1050,17 @@ method = __ecereNameSpace__ecere__com__eClass_FindMethod(_class, "Stats", module
 if(method)
 __ecereVMethodID___ecereNameSpace__ecere__sys__FileSystem_Stats = method->vid;
 __ecereClass___ecereNameSpace__ecere__sys__NamedLink = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "ecere::sys::NamedLink");
+__ecereClass___ecereNameSpace__ecere__sys__NamedLink64 = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "ecere::sys::NamedLink64");
 __ecereClass___ecereNameSpace__ecere__sys__OldLink = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "ecere::sys::OldLink");
 __ecereClass___ecereNameSpace__ecere__sys__OldList = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "ecere::sys::OldList");
 __ecereClass___ecereNameSpace__ecere__sys__StringBTNode = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "ecere::sys::StringBTNode");
 __ecereClass___ecereNameSpace__ecere__sys__TempFile = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "ecere::sys::TempFile");
+__ecereClass_float = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "float");
 __ecereClass_int = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "int");
+__ecereClass_int64 = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "int64");
 __ecereClass_uint = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "uint");
 __ecereClass_uint64 = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "uint64");
+__ecereClass_uintptr = __ecereNameSpace__ecere__com__eSystem_FindClass(module, "uintptr");
 __ecereCreateModuleInstances_i18n();
 __ecereNameSpace__ecere__LoadTranslatedStrings(module, "ecere");
 }
