@@ -15,6 +15,12 @@
 #define bool _bool
 #include <utime.h>
 #include <dlfcn.h>
+#if defined(__APPLE__)
+#include <mach-o/dyld.h>
+#endif
+#if defined(__FreeBSD__)
+#include <sys/sysctl.h>
+#endif
 #undef bool
 #endif
 
@@ -44,6 +50,10 @@ typedef unsigned long long uint64;
 #define MAX_FILENAME 274
 #define MAX_EXTENSION 17
 
+FILE *eC_stdin(void)  { return stdin; }
+FILE *eC_stdout(void) { return stdout; }
+FILE *eC_stderr(void) { return stderr; }
+
 void __ecereNameSpace__ecere__com__eSystem_Delete(void * memory);
 void * __ecereNameSpace__ecere__com__eSystem_New0(unsigned int size);
 void * __ecereNameSpace__ecere__com__eSystem_Renew(void * memory, unsigned int size);
@@ -86,10 +96,51 @@ typedef enum { unknown, win32, tux, apple } Platform;
 Platform runtimePlatform = win32;
 #elif defined(__APPLE__)
 Platform runtimePlatform = apple;
-#elif defined(__linux__)
+#else //if defined(__linux__)
 Platform runtimePlatform = tux;
-#else
-Platform runtimePlatform = unknown;
+/*#else
+Platform runtimePlatform = unknown;    // 'linux' is used as a catch all UNIX platform for now
+*/
+#endif
+
+#if !defined(ECERE_NOFILE) && defined(__unix__) && !defined(__linux__)
+
+typedef struct _DualPipe _DualPipe;
+
+void DualPipe_Destructor(_DualPipe * dp);
+bool DualPipe_Getc(_DualPipe * dp, char * ch);
+bool DualPipe_Eof(_DualPipe * dp);
+void DualPipe_Wait(_DualPipe * dp);
+
+_DualPipe * _DualPipeOpen(int mode, char * commandLine, char * env, void ** inputPtr, void ** outputPtr);
+
+static bool DualPipe_GetLine(FILE * p, char *s, int max)
+{
+   int c = 0;
+   bool result = true;
+   s[c]=0;
+   if(feof(p))
+      result = false;
+   else
+   {
+      while(c<max-1)
+      {
+         int ch = 0;
+         if((ch = fgetc(p)) == EOF)
+         {
+            result = false;
+            break;
+         }
+         if(ch =='\n') 
+            break;
+         if(ch !='\r')
+            s[c++]=(char)ch;
+      }
+   }
+   s[c]=0;
+   return result || c > 1;
+}
+
 #endif
 
 bool Instance_LocateModule(char * name, char * fileName)
@@ -229,8 +280,76 @@ bool Instance_LocateModule(char * name, char * fileName)
       }
       fclose(f);
    }
+#if !defined(ECERE_NOFILE) && !defined(__linux__)
+   if(name && name[0])
+   {
+      // Couldn't locate libraries with /proc/curmap/map, attempt with ldd
+      FILE * in = null, * out = null;
+      _DualPipe * p;
+      char command[MAX_LOCATION];
+      snprintf(command, sizeof(command), "ldd /proc/%d/file", (int)getpid());
+      p  = _DualPipeOpen(1, command, null, &in, &out);
+      if(p)
+      {
+         bool result = false;
+         char line[1025];
+         int nameLen = strlen(name);
+         while(DualPipe_GetLine(in, line, sizeof(line)))
+         {
+            char * path = strstr(line, "/");
+            if(path)
+            {
+               int pathLen = strlen(path);
+               char * subStr;
+               path[--pathLen] = 0;
+               subStr = RSearchString(path, name, pathLen, false, false);
+               if(subStr)
+               {
+                  if(( *(subStr-1) == '/' || !strncmp(subStr - 4, "/lib", 4)) &&
+                     (!subStr[nameLen] || !strncmp(subStr + nameLen, ".so", 3)))
+                  {
+                     char * space = strchr(path, ' ');
+                     if(space) *space = 0;
+                     strcpy(fileName, path);
+                     result = true;
+                  }
+               }
+            }
+         }
+         DualPipe_Wait(p);
+         fclose(in);
+         DualPipe_Destructor(p);
+         return result;
+      }
+   }
+#endif
    if(!name || !name[0])
    {
+#if defined(__FreeBSD__)
+      {
+         int mib[4] = { CTL_KERN, KERN_PROC, KERN_PROC_PATHNAME, -1 };
+         size_t cb = MAX_LOCATION;
+         fileName[0] = 0;
+         sysctl(mib, 4, fileName, &cb, null, 0);
+         if(fileName[0])
+            return true;
+      }  
+#endif
+#if !defined(__linux__)
+      {
+         char * env;
+         if(!access("/proc/curproc/file", F_OK))
+         {
+            strcpy(fileName, "/proc/curproc/file");
+            return true;
+         }
+         if((env = getenv("_")))
+         {
+            strcpy(fileName, env);
+            return true;
+         }
+      }
+#endif
       strcpy(fileName, exeLocation);
       return true;
    }
@@ -240,7 +359,7 @@ bool Instance_LocateModule(char * name, char * fileName)
 
 void Instance_COM_Initialize(int argc, char ** argv, char ** parsedCommand, int * argcPtr, char *** argvPtr)
 {
-#if !defined(__WIN32__)
+#if !defined(__WIN32__) && !defined(ECERE_BOOTSTRAP)
    // Disable stdout buffering on Unix
    setvbuf(stdout, null, _IONBF, 0);
 #endif
@@ -261,11 +380,15 @@ void Instance_COM_Initialize(int argc, char ** argv, char ** parsedCommand, int
 #endif
 }
 
-void * Instance_Module_Load(char * name, void ** Load, void ** Unload)
+void * Instance_Module_Load(const char * libLocation, const char * name, void ** Load, void ** Unload)
 {
    char fileName[MAX_LOCATION];
    char extension[MAX_EXTENSION];
    void * library = null;
+#if defined(__unix__) || defined(__APPLE__)
+   int attempts = 0;
+   char * paths[] = { null, "/usr/lib/ec/lib", "/usr/lib32/ec/lib" };
+#endif
 
    *Load = null;
    *Unload = null;
@@ -283,17 +406,21 @@ void * Instance_Module_Load(char * name, void ** Load, void ** Unload)
    }
    if(library)
    {
+#ifdef _WIN64
+      *Load = (void *)GetProcAddress(library, "__ecereDll_Load");
+      *Unload = (void *)GetProcAddress(library, "__ecereDll_Unload");
+#else
       *Load = (void *)GetProcAddress(library, "__ecereDll_Load@4");
       *Unload = (void *)GetProcAddress(library, "__ecereDll_Unload@4");
+#endif
       if(!*Load)
          FreeLibrary(library);
    }
 #elif defined(__unix__) || defined(__APPLE__)
-#if defined(__ANDROID__)
-   sprintf(fileName, "/data/data/com.ecere.%s/lib/lib", name);
-#else
-   strcpy(fileName, "lib");
-#endif
+   if(libLocation)
+      strcpy(fileName, libLocation);
+   else
+      strcpy(fileName, "lib");
    strcat(fileName, name);
    GetExtension(fileName, extension);
    if(!extension[0])
@@ -304,14 +431,20 @@ void * Instance_Module_Load(char * name, void ** Load, void ** Unload)
 #endif
 
    library = dlopen(fileName, RTLD_LAZY);
-   if(!library)
+   while(!library && attempts < sizeof(paths)/sizeof(paths[0]))
    {
+      if(paths[attempts])
+         strcpy(fileName, paths[attempts++]);
+      else
+      {
+         attempts++;
 #ifdef DEB_HOST_MULTIARCH
-      strcpy(fileName, DEB_HOST_MULTIARCH);
-      strcat(fileName, "/ec/lib");
+         strcpy(fileName, DEB_HOST_MULTIARCH);
+         strcat(fileName, "/ec/lib");
 #else
-      strcpy(fileName, "/usr/lib/ec/lib");
+         continue;
 #endif
+      }
       strcat(fileName, name);
       GetExtension(fileName, extension);
       if(!extension[0])
@@ -376,3 +509,9 @@ void Instance_Module_Free(void * library)
       dlclose(library);
 #endif
 }
+
+#if defined(_DEBUG)
+   void InternalModuleLoadBreakpoint()
+   {
+   }
+#endif
